@@ -53,7 +53,7 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
     df = devutils.clean_rows_with_na( df=df, cols_to_clean_na=cols_to_clean_na )
 
     # Map industry dictionary
-    df = df.replace( {'Industry': industry_dictionary} )
+    df['Industry'] = df['Industry'].map(industry_dictionary)
     logging.info( df['Industry'].value_counts() )
 
     # Fill NA with "Uknown" in the  columns specified in the config
@@ -63,8 +63,8 @@ def preprocessing_training_common(df, config, industry_dictionary, state_diction
     df = devutils.clean_mxtype_using_dictionary( df=df, mx_bv_dict=mx_bv_dictionary,
                                                  mx_prob_dict=mx_prob_dictionary )
 
-    # Map State dictionary
-    df = df.replace( {'State': state_dictionary} )
+    # map states dictionary
+    df['State'] = df['State'].map( state_dictionary )
     logging.info( df['State'].value_counts() )
 
     # add the month of the transaction
