@@ -62,8 +62,8 @@ def set_dataframe_columntypes(df):
         df['Type'] = df['Type'].astype('object')
     if 'Specialties' in df:
         df['Specialties'] = df['Specialties'].astype('object')
-    if 'MXtype' in df:
-        df['MXtype'] = df['MXtype'].astype('object')
+    if 'MXType' in df:
+        df['MXType'] = df['MXType'].astype('object')
     if 'Technologies' in df:
         df['Technologies'] = df['Technologies'].astype('object')
     if 'Country' in df:
@@ -437,16 +437,16 @@ def clean_mxtype(df,mxtypes):
     """
 
     :param df: Input Dataset
-    :param mxtypes: MXtypes to maintain ( the rest will go to others)
+    :param mxtypes: MXTypes to maintain ( the rest will go to others)
     :return df: processed Dataset
     """
 
-    if 'MXtype' not in df.columns:
-        raise Exception ("MXtype column not preset ( Check Caps)")
+    if 'MXType' not in df.columns:
+        raise Exception ("MXType column not preset ( Check Caps)")
     logger.info('Defining MXTypes')
     logger.info(f'legal MXTypes: {mxtypes}')
-    df.loc[~df['MXtype'].isin(mxtypes), 'MXtype'] = 'Others'
-    logger.info(f'{df.MXtype.value_counts()}')
+    df.loc[~df['MXType'].isin(mxtypes), 'MXType'] = 'Others'
+    logger.info(f'{df.MXType.value_counts()}')
     return df
 
 
@@ -454,18 +454,18 @@ def clean_mxtype_using_dictionary(df,mx_bv_dict,mx_prob_dict):
     """
 
     :param df: Input Dataset
-    :param mx_bv_dict: MXtypes dictionary by bv performance
-    :param mx_prob_dict: MXtypes dictionary by prob performance
+    :param mx_bv_dict: MXTypes dictionary by bv performance
+    :param mx_prob_dict: MXTypes dictionary by prob performance
     :return df: processed Dataset
     """
 
-    if 'MXtype' not in df.columns:
-        raise Exception ("MXtype column not preset ( Check Caps)")
+    if 'MXType' not in df.columns:
+        raise Exception ("MXType column not preset ( Check Caps)")
     logger.info('Defining MXTypes')
-    df['mx_bv'] = df['MXtype']
+    df['mx_bv'] = df['MXType']
     df = df.replace({'mx_bv': mx_bv_dict})
     logger.info(f'{df.mx_bv.value_counts()}')
-    df['mx_prob'] = df['MXtype']
+    df['mx_prob'] = df['MXType']
     df = df.replace( {'mx_prob': mx_prob_dict} )
     logger.info(f'{df.mx_prob.value_counts()}')
     return df
